package jalview.schemes;

import static org.testng.Assert.assertEquals;

import java.awt.Color;

import org.testng.annotations.Test;

public class BuriedColourSchemeTest
{
  /**
   * Buried colours are derived from the scores in ResidueProperties.buried A =
   * 1.7, R = 0.1, N = 0.4, D = 0.4... min = 0.05 max = 4.6
   * <p>
   * scores are scaled to c 0-1 between min and max and colour is (0, 1-c, c)
   */
  @Test(groups = "Functional")
  public void testFindColour()
  {
    ScoreColourScheme scheme = new BuriedColourScheme();

    float min = 0.05f;
    float max = 4.6f;
    assertEquals((float) scheme.min, min);
    assertEquals((float) scheme.max, max);

    float a = (1.7f - min) / (max - min);
    Color expected = new Color(0, 1 - a, a);
    assertEquals(scheme.findColour('A', 0, null), expected);

    float d = (0.4f - min) / (max - min);
    expected = new Color(0, 1 - d, d);
    assertEquals(scheme.findColour('D', 0, null), expected);

    assertEquals(scheme.findColour('-', 0, null), Color.WHITE);
    assertEquals(scheme.findColour('A', 0, null), new Color(0, 163, 92));
    assertEquals(scheme.findColour('r', 0, null), new Color(0, 252, 3));
    assertEquals(scheme.findColour('n', 0, null), new Color(0, 235, 20));
    assertEquals(scheme.findColour('d', 0, null), new Color(0, 235, 20));
    assertEquals(scheme.findColour('c', 0, null), new Color(0, 0, 255));
    assertEquals(scheme.findColour('q', 0, null), new Color(0, 241, 14));
    assertEquals(scheme.findColour('e', 0, null), new Color(0, 241, 14));
    assertEquals(scheme.findColour('g', 0, null), new Color(0, 157, 98));
    assertEquals(scheme.findColour('h', 0, null), new Color(0, 213, 42));
    assertEquals(scheme.findColour('I', 0, null), new Color(0, 84, 171));
    assertEquals(scheme.findColour('L', 0, null), new Color(0, 123, 132));
    assertEquals(scheme.findColour('K', 0, null), new Color(0, 255, 0));
    assertEquals(scheme.findColour('M', 0, null), new Color(0, 151, 104));
    assertEquals(scheme.findColour('F', 0, null), new Color(0, 135, 120));
    assertEquals(scheme.findColour('P', 0, null), new Color(0, 224, 31));
    assertEquals(scheme.findColour('S', 0, null), new Color(0, 213, 42));
    assertEquals(scheme.findColour('T', 0, null), new Color(0, 219, 36));
    assertEquals(scheme.findColour('W', 0, null), new Color(0, 168, 87));
    assertEquals(scheme.findColour('Y', 0, null), new Color(0, 230, 25));
    assertEquals(scheme.findColour('v', 0, null), new Color(0, 95, 160));
    assertEquals(scheme.findColour('b', 0, null), new Color(0, 235, 20));
    assertEquals(scheme.findColour('z', 0, null), new Color(0, 241, 14));
    assertEquals(scheme.findColour('x', 0, null), new Color(0, 182, 73));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 255, 0));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 255, 0));
  }

}
