package jalview.schemes;

import static org.testng.Assert.assertEquals;

import java.awt.Color;

import org.testng.annotations.Test;

public class HelixColourSchemeTest
{
  /**
   * Turn colours are based on the scores in ResidueProperties.helix A = 1.42, R
   * = 0.98, N = 0.67, D = 1.01... min = 0.57 max = 1.51
   * <p>
   * scores are scaled to c 0-1 between min and max and colour is (c, 1-c, c)
   */
  @Test(groups = "Functional")
  public void testFindColour()
  {
    ScoreColourScheme scheme = new HelixColourScheme();

    float min = 0.57f;
    float max = 1.51f;
    assertEquals((float) scheme.min, min);
    assertEquals((float) scheme.max, max);

    float a = (1.42f - min) / (max - min);
    assertEquals(scheme.findColour('A', 0, null), new Color(a, 1 - a, a));

    float d = (1.01f - min) / (max - min);
    assertEquals(scheme.findColour('D', 0, null), new Color(d, 1 - d, d));

    assertEquals(scheme.findColour('-', 0, null), Color.WHITE);

    assertEquals(scheme.findColour('A', 0, null), new Color(231, 24, 231));
    assertEquals(scheme.findColour('r', 0, null), new Color(111, 144, 111));
    assertEquals(scheme.findColour('n', 0, null), new Color(27, 228, 27));
    assertEquals(scheme.findColour('d', 0, null), new Color(119, 136, 119));
    assertEquals(scheme.findColour('c', 0, null), new Color(35, 220, 35));
    assertEquals(scheme.findColour('q', 0, null), new Color(146, 109, 146));
    assertEquals(scheme.findColour('e', 0, null), new Color(255, 0, 255));
    assertEquals(scheme.findColour('g', 0, null), new Color(0, 255, 0));
    assertEquals(scheme.findColour('h', 0, null), new Color(117, 138, 117));
    assertEquals(scheme.findColour('I', 0, null), new Color(138, 117, 138));
    assertEquals(scheme.findColour('L', 0, null), new Color(174, 81, 174));
    assertEquals(scheme.findColour('K', 0, null), new Color(160, 95, 160));
    assertEquals(scheme.findColour('M', 0, null), new Color(239, 16, 239));
    assertEquals(scheme.findColour('F', 0, null), new Color(152, 103, 152));
    assertEquals(scheme.findColour('P', 0, null), new Color(0, 255, 0));
    assertEquals(scheme.findColour('S', 0, null), new Color(54, 201, 54));
    assertEquals(scheme.findColour('T', 0, null), new Color(71, 184, 71));
    assertEquals(scheme.findColour('W', 0, null), new Color(138, 117, 138));
    assertEquals(scheme.findColour('Y', 0, null), new Color(33, 222, 33));
    assertEquals(scheme.findColour('v', 0, null), new Color(133, 122, 133));
    assertEquals(scheme.findColour('b', 0, null), new Color(73, 182, 73));
    assertEquals(scheme.findColour('z', 0, null), new Color(201, 54, 201));
    assertEquals(scheme.findColour('x', 0, null), new Color(117, 138, 117));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 255, 0));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 255, 0));
  }

}
