package jalview.schemes;

import static org.testng.Assert.assertEquals;

import java.awt.Color;

import org.testng.annotations.Test;

public class HydrophobicColourSchemeTest
{
  /**
   * Turn colours are based on the scores in ResidueProperties.hyd A = 1.8, R =
   * -4.5, N = -3.5, D = -3.5... min = -3.9 max = 4.5
   * <p>
   * scores are scaled to c 0-1 between min and max and colour is (c, 0, 1-c)
   */
  @Test(groups = "Functional")
  public void testFindColour()
  {
    ScoreColourScheme scheme = new HydrophobicColourScheme();

    float min = -4.5f;
    float max = 4.5f;
    assertEquals((float) scheme.min, min);
    assertEquals((float) scheme.max, max);

    float a = (1.8f - min) / (max - min);
    assertEquals(scheme.findColour('A', 0, null), new Color(a, 0, 1 - a));

    float d = (-3.5f - min) / (max - min);
    assertEquals(scheme.findColour('D', 0, null), new Color(d, 0, 1 - d));

    assertEquals(scheme.findColour('-', 0, null), Color.WHITE);
    assertEquals(scheme.findColour('A', 0, null), new Color(179, 0, 76));
    assertEquals(scheme.findColour('r', 0, null), new Color(0, 0, 255));
    assertEquals(scheme.findColour('n', 0, null), new Color(28, 0, 227));
    assertEquals(scheme.findColour('d', 0, null), new Color(28, 0, 227));
    assertEquals(scheme.findColour('c', 0, null), new Color(198, 0, 57));
    assertEquals(scheme.findColour('q', 0, null), new Color(28, 0, 227));
    assertEquals(scheme.findColour('e', 0, null), new Color(28, 0, 227));
    assertEquals(scheme.findColour('g', 0, null), new Color(116, 0, 139));
    assertEquals(scheme.findColour('h', 0, null), new Color(37, 0, 218));
    assertEquals(scheme.findColour('I', 0, null), new Color(255, 0, 0));
    assertEquals(scheme.findColour('L', 0, null), new Color(235, 0, 20));
    assertEquals(scheme.findColour('K', 0, null), new Color(17, 0, 238));
    assertEquals(scheme.findColour('M', 0, null), new Color(181, 0, 74));
    assertEquals(scheme.findColour('F', 0, null), new Color(207, 0, 48));
    assertEquals(scheme.findColour('P', 0, null), new Color(82, 0, 173));
    assertEquals(scheme.findColour('S', 0, null), new Color(105, 0, 150));
    assertEquals(scheme.findColour('T', 0, null), new Color(108, 0, 147));
    assertEquals(scheme.findColour('W', 0, null), new Color(102, 0, 153));
    assertEquals(scheme.findColour('Y', 0, null), new Color(91, 0, 164));
    assertEquals(scheme.findColour('v', 0, null), new Color(247, 0, 9));
    assertEquals(scheme.findColour('b', 0, null), new Color(28, 0, 227));
    assertEquals(scheme.findColour('z', 0, null), new Color(28, 0, 227));
    assertEquals(scheme.findColour('x', 0, null), new Color(114, 0, 141));
    assertEquals(scheme.findColour('?', 0, null), new Color(128, 0, 128));
    assertEquals(scheme.findColour('?', 0, null), new Color(128, 0, 128));
  }

}
