package jalview.schemes;

import static org.testng.Assert.assertEquals;

import java.awt.Color;

import org.testng.annotations.Test;

public class StrandColourSchemeTest
{
  /**
   * Turn colours are based on the scores in ResidueProperties.strand A = 0.83,
   * R = 0.93, N = 0.89, D = 0.54... min = 0.37 max = 1.7
   * <p>
   * scores are scaled to c 0-1 between min and max and colour is (c, c, 1-c)
   */
  @Test(groups = "Functional")
  public void testFindColour()
  {
    ScoreColourScheme scheme = new StrandColourScheme();

    float min = 0.37f;
    float max = 1.7f;
    assertEquals((float) scheme.min, min);
    assertEquals((float) scheme.max, max);

    float a = (0.83f - min) / (max - min);
    assertEquals(scheme.findColour('A', 0, null), new Color(a, a, 1 - a));

    float d = (0.54f - min) / (max - min);
    assertEquals(scheme.findColour('D', 0, null), new Color(d, d, 1 - d));

    assertEquals(scheme.findColour('-', 0, null), Color.WHITE);
    assertEquals(scheme.findColour('A', 0, null), new Color(88, 88, 167));
    assertEquals(scheme.findColour('r', 0, null), new Color(107, 107, 148));
    assertEquals(scheme.findColour('n', 0, null), new Color(100, 100, 155));
    assertEquals(scheme.findColour('d', 0, null), new Color(33, 33, 222));
    assertEquals(scheme.findColour('c', 0, null), new Color(157, 157, 98));
    assertEquals(scheme.findColour('q', 0, null), new Color(140, 140, 115));
    assertEquals(scheme.findColour('e', 0, null), new Color(0, 0, 255));
    assertEquals(scheme.findColour('g', 0, null), new Color(73, 73, 182));
    assertEquals(scheme.findColour('h', 0, null), new Color(96, 96, 159));
    assertEquals(scheme.findColour('I', 0, null), new Color(236, 236, 19));
    assertEquals(scheme.findColour('L', 0, null), new Color(178, 178, 77));
    assertEquals(scheme.findColour('K', 0, null), new Color(71, 71, 184));
    assertEquals(scheme.findColour('M', 0, null), new Color(130, 130, 125));
    assertEquals(scheme.findColour('F', 0, null), new Color(194, 194, 61));
    assertEquals(scheme.findColour('P', 0, null), new Color(35, 35, 220));
    assertEquals(scheme.findColour('S', 0, null), new Color(73, 73, 182));
    assertEquals(scheme.findColour('T', 0, null), new Color(157, 157, 98));
    assertEquals(scheme.findColour('W', 0, null), new Color(192, 192, 63));
    assertEquals(scheme.findColour('Y', 0, null), new Color(211, 211, 44));
    assertEquals(scheme.findColour('v', 0, null), new Color(255, 255, 0));
    assertEquals(scheme.findColour('b', 0, null), new Color(67, 67, 188));
    assertEquals(scheme.findColour('z', 0, null), new Color(71, 71, 184));
    assertEquals(scheme.findColour('x', 0, null), new Color(121, 121, 134));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 0, 255));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 0, 255));
  }

}
