package jalview.schemes;

import static org.testng.Assert.assertEquals;

import java.awt.Color;

import org.testng.annotations.Test;

public class TurnColourSchemeTest
{
  /**
   * Turn colours are based on the scores in ResidueProperties.turn A = 0.66, R
   * = 0.95, N = 1.56, D = 1.46... min = 0.47 max = 1.56
   * <p>
   * scores are scaled to c 0-1 between min and max and colour is (c, 1-c, 1-c)
   */
  @Test(groups = "Functional")
  public void testFindColour()
  {
    ScoreColourScheme scheme = new TurnColourScheme();

    float min = 0.47f;
    float max = 1.56f;
    assertEquals((float) scheme.min, min);
    assertEquals((float) scheme.max, max);

    float a = (0.66f - min) / (max - min);
    assertEquals(scheme.findColour('A', 0, null),
            new Color(a, 1 - a, 1 - a));

    float d = (1.46f - min) / (max - min);
    assertEquals(scheme.findColour('D', 0, null),
            new Color(d, 1 - d, 1 - d));

    assertEquals(scheme.findColour('-', 0, null), Color.WHITE);
    assertEquals(scheme.findColour('A', 0, null), new Color(44, 211, 211));
    assertEquals(scheme.findColour('r', 0, null), new Color(112, 143, 143));
    assertEquals(scheme.findColour('n', 0, null), new Color(255, 0, 0));
    assertEquals(scheme.findColour('d', 0, null), new Color(232, 23, 23));
    assertEquals(scheme.findColour('c', 0, null), new Color(168, 87, 87));
    assertEquals(scheme.findColour('q', 0, null), new Color(119, 136, 136));
    assertEquals(scheme.findColour('e', 0, null), new Color(63, 192, 192));
    assertEquals(scheme.findColour('g', 0, null), new Color(255, 0, 0));
    assertEquals(scheme.findColour('h', 0, null), new Color(112, 143, 143));
    assertEquals(scheme.findColour('I', 0, null), new Color(0, 255, 255));
    assertEquals(scheme.findColour('L', 0, null), new Color(28, 227, 227));
    assertEquals(scheme.findColour('K', 0, null), new Color(126, 129, 129));
    assertEquals(scheme.findColour('M', 0, null), new Color(30, 225, 225));
    assertEquals(scheme.findColour('F', 0, null), new Color(30, 225, 225));
    assertEquals(scheme.findColour('P', 0, null), new Color(246, 9, 9));
    assertEquals(scheme.findColour('S', 0, null), new Color(225, 30, 30));
    assertEquals(scheme.findColour('T', 0, null), new Color(115, 140, 140));
    assertEquals(scheme.findColour('W', 0, null), new Color(115, 140, 140));
    assertEquals(scheme.findColour('Y', 0, null), new Color(157, 98, 98));
    assertEquals(scheme.findColour('v', 0, null), new Color(7, 248, 248));
    assertEquals(scheme.findColour('b', 0, null), new Color(243, 12, 12));
    assertEquals(scheme.findColour('z', 0, null), new Color(91, 164, 164));
    assertEquals(scheme.findColour('x', 0, null), new Color(124, 131, 131));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 255, 255));
    assertEquals(scheme.findColour('?', 0, null), new Color(0, 255, 255));
  }

}
